pub struct BlockRequest {
pub transaction_hash: Hash,
pub transaction: Arc<Transaction>,
pub known_utxos: Arc<HashMap<OutPoint, OrderedUtxo>>,
pub height: Height,
pub time: DateTime<Utc>,
}Expand description
A request to verify a transaction as part of a block.
Fields
transaction_hash: HashThe mined transaction ID of transaction.
Used for efficiency: callers should already have this,
so no need to recompute it in the verifier.
transaction: Arc<Transaction>The transaction itself.
known_utxos: Arc<HashMap<OutPoint, OrderedUtxo>>Additional UTXOs which are known at the time of verification.
height: HeightThe height of the block containing this transaction.
time: DateTime<Utc>The time that the block was mined.