pub struct BlockResponse {
pub tx_id: UnminedTxId,
pub miner_fee: Option<Amount<NonNegative>>,
pub sigops: u32,
}Expand description
A response to a block transaction verification request.
Fields
tx_id: UnminedTxIdThe witnessed transaction ID for this transaction.
BlockResponse responses can be uniquely identified by
UnminedTxId::mined_id, because the block’s authorizing data root
will be checked during contextual validation.
miner_fee: Option<Amount<NonNegative>>The miner fee for this transaction.
None for coinbase transactions.
Consensus
The remaining value in the transparent transaction value pool of a coinbase transaction is destroyed.
sigops: u32The total number of transparent signature operations counted for block verification in this transaction: legacy sigops plus P2SH sigops.
This value is used to enforce the block-level MAX_BLOCK_SIGOPS limit.