pub struct MempoolResponse {
pub transaction: VerifiedUnminedTx,
pub spent_mempool_outpoints: Vec<OutPoint>,
}Expand description
A response to a mempool transaction verification request.
Fields
transaction: VerifiedUnminedTxThe full content of the verified mempool transaction. Also contains the transaction fee and other associated fields.
Mempool transactions always have a transaction fee, because coinbase transactions are rejected from the mempool.
MempoolResponse responses are uniquely identified by the
UnminedTxId variant for their transaction version.
spent_mempool_outpoints: Vec<OutPoint>A list of spent transparent::OutPoints that were found in
the mempool’s list of created_outputs.
Used by the mempool to determine dependencies between transactions in the mempool and to avoid adding transactions with missing spends to its verified set.